[![Anaconda-Server Badge](https://anaconda.org/conda-forge/pdspy/badges/installer/conda.svg)](https://conda.anaconda.org/conda-forge)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/pdspy/badges/version.svg)](https://anaconda.org/conda-forge/pdspy)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/pdspy/badges/platforms.svg)](https://anaconda.org/conda-forge/pdspy)
[![Documentation Status](https://readthedocs.org/projects/pdspy/badge/?version=latest)](https://pdspy.readthedocs.io/en/latest/?badge=latest)

# pdspy: A MCMC Tool for Continuum and Spectral Line Radiative Transfer Modeling

Welcome to the GitHub page for pdspy! This code is meant to fit Monte Carlo Radiative Transfer models for protostellar/protoplanetary disks to ALMA continuum and spectral line datasets using Markov Chain Monte Carlo fitting.

Further capabilities (e.g. fitting spectral line data with a radiative equilibrium calculation) are being developed. If you are interested in new features, do let me know and I would be happy to either add them myself, or to work with you to add them. The documentation is currently included below, but will be ported to a more extensive, better laid out format soon. 

If you are interested in making use of the code, please check out the [documentation](http://pdspy.readthedocs.io).

For more extensive details on what the code does, please see these papers:

   + [Disk Masses for Embedded Class I Protostars in the Taurus Molecular Cloud](https://ui.adsabs.harvard.edu/abs/2017ApJ...851...45S/abstract)
   + [High-precision Dynamical Masses of Pre-main-sequence Stars with ALMA and Gaia](https://ui.adsabs.harvard.edu/abs/2019ApJ...874..136S/abstract)
   
If you have any questions about using the code (or this documentation), requests for features, or suggestions for improvement, please don't hesitate to send me an e-mail.
